<?php
$logFile = __DIR__ . '/upload_log.txt';
$lockFile = __DIR__ . '/script.lock';

function logMessage($message) {
    global $logFile;
    $timestamp = date("Y-m-d H:i:s");
    $logEntry = "[$timestamp] $message" . PHP_EOL;
    file_put_contents($logFile, $logEntry, FILE_APPEND);
}

// Check if the lock file exists
if (file_exists($lockFile)) {
    logMessage("Script is already running.");
    exit;
}

// Create the lock file
file_put_contents($lockFile, getmypid());

function removeLockFile() {
    global $lockFile;
    unlink($lockFile);
}

// Ensure the lock file is removed even if the script exits unexpectedly
register_shutdown_function('removeLockFile');

function getLargestFile($dir) {
    $largestFile = '';
    $largestSize = 0;
    
    $iterator = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($dir, RecursiveDirectoryIterator::SKIP_DOTS));
    foreach ($iterator as $file) {
        if ($file->isFile()) {
            $fileSize = $file->getSize();
            if ($fileSize > $largestSize) {
                $largestSize = $fileSize;
                $largestFile = $file->getPathname();
            }
        }
    }
    return $largestFile;
}

function executeCommand($command, $env = null) {
    $descriptorSpec = [
        0 => ["pipe", "r"],  // stdin is a pipe that the child will read from
        1 => ["pipe", "w"],  // stdout is a pipe that the child will write to
        2 => ["pipe", "w"]   // stderr is a pipe that the child will write to
    ];

    $process = proc_open($command, $descriptorSpec, $pipes, null, $env);

    if (is_resource($process)) {
        // Close stdin pipe
        fclose($pipes[0]);

        // Read stdout and stderr
        $stdout = stream_get_contents($pipes[1]);
        fclose($pipes[1]);

        $stderr = stream_get_contents($pipes[2]);
        fclose($pipes[2]);

        // Close the process and get the return value
        $returnValue = proc_close($process);

        return [
            'stdout' => $stdout,
            'stderr' => $stderr,
            'return_value' => $returnValue
        ];
    }

    return false;
}

$pwd = "/home/saadit5/public_html/media";
$directories = array_filter(glob($pwd . '/*'), 'is_dir');

foreach ($directories as $dir) {
    if (realpath($dir) === $pwd || strpos(realpath($dir), $pwd . DIRECTORY_SEPARATOR) !== 0) {
        // Skip if it's the current directory itself or if it somehow resolves outside the current directory
        logMessage("Skipping directory outside the current working directory: $dir");
        continue;
    }

    $files = scandir($dir);
    $files = array_diff($files, array('.', '..'));
    
    if (!empty($files)) {
        $aria2Files = glob($dir . '/*.aria2');
        
        if (empty($aria2Files)) {
            logMessage("Processing directory: $dir");

            $largestFile = getLargestFile($dir);
            
            if ($largestFile) {
                logMessage("Largest file found: $largestFile");

                // Use the absolute path to telegram-upload
                $telegramUploadPath = '/usr/local/bin/telegram-upload';
                //$command = "$telegramUploadPath -d --print-file-id --to t.me/fsdghana " . escapeshellarg($largestFile);
                $command = "$telegramUploadPath -d --print-file-id --to -1001558550793 " . escapeshellarg($largestFile);
                logMessage("Executing command: $command");

                // Set environment variables for UTF-8
                $env = [
                    'LC_ALL' => 'en_US.UTF-8',
                    'LANG' => 'en_US.UTF-8'
                ];

                // Execute the command and capture the output and errors
                $result = executeCommand($command, $env);
                if ($result !== false) {
                    logMessage("Command stdout: " . $result['stdout']);
                    logMessage("Command stderr: " . $result['stderr']);
                    logMessage("Command return value: " . $result['return_value']);

                        $aria2File = $dir . '/' . 'done.aria2';
                        file_put_contents($aria2File, '');
                        logMessage("Created file: $aria2File");
                } else {
                    logMessage("Failed to execute command.");
                }
            } else {
                logMessage("No files found in directory: $dir");
            }
        } else {
            logMessage(".aria2 file found in directory: $dir, skipping...");
        }
    } else {
        logMessage("Directory is empty: $dir");
    }
}
?>
